summaryrefslogtreecommitdiffstats
path: root/kbabel/common/catalog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/common/catalog.h')
-rw-r--r--kbabel/common/catalog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kbabel/common/catalog.h b/kbabel/common/catalog.h
index 74fbcdd7..dd8c3a30 100644
--- a/kbabel/common/catalog.h
+++ b/kbabel/common/catalog.h
@@ -128,11 +128,11 @@ public:
/**
* A constructor for an empty message catalog.
* @param tqparent tqparent @ref TQObject for this catalog
* @param name unique name for this object
* @param configFile configuration file to read config from
*/
- Catalog(TQObject* tqparent=0, const char* name=0, TQString projectFile = TQString() );
+ Catalog(TQObject* parent=0, const char* name=0, TQString projectFile = TQString() );
/**
* Deprecated. A copy constructor. Do not use since each Catalog registers
@@ -128,11 +128,11 @@ public:
/**
* A constructor for an empty message catalog.
- * @param tqparent tqparent @ref TQObject for this catalog
+ * @param parent parent @ref TQObject for this catalog
* @param name unique name for this object
* @param configFile configuration file to read config from